RecordFormat

Enum RecordFormat 

pub enum RecordFormat {
    Json(JsonFlavor),
    Csv(CsvParserConfig),
    Parquet(SqlSerdeConfig),
    Raw(String),
}
Descriptor that specifies the format in which records are received or into which they should be encoded before sending.

Variants