pub struct OutputCollectionHandles {
pub key_schema: Option<Relation>,
pub value_schema: Relation,
pub index_of: Option<SqlIdentifier>,
pub alias_as_index: Option<SqlIdentifier>,
pub integrate_handle: Option<Arc<dyn SerBatchReaderHandle>>,
pub delta_handle: Box<dyn SerBatchReaderHandle>,
pub enable_count: Arc<AtomicUsize>,
}Expand description
A set of stream handles associated with each output collection.
Fields
key_schema: Option<Relation>Schema of the keys in the stream.
Only set for indexed Z-sets.
value_schema: RelationSchema of the values in the stream.
If the stream is an indexed Z-set, this is the schema of the values in the stream; if it is a Z-set, this is the schema of the keys in the stream.
index_of: Option<SqlIdentifier>Set when this stream is an index of another stream.
alias_as_index: Option<SqlIdentifier>Set when the same stream is used to represent a view and its index.
integrate_handle: Option<Arc<dyn SerBatchReaderHandle>>A handle to a snapshot of a materialized table/view.
delta_handle: Box<dyn SerBatchReaderHandle>A stream of changes to the collection.
enable_count: Arc<AtomicUsize>Reference to the enable count of the accumulator used to collect updates to this stream. Incremented every time an output connector is attached to this stream; decremented when the output connector is detached.
Implementations
Sourceimpl OutputCollectionHandles
impl OutputCollectionHandles
Sourcepub fn is_indexed(&self) -> bool
pub fn is_indexed(&self) -> bool
Stream is an indexed Z-set.