ConfigError

Enum ConfigError 

pub enum ConfigError {
Show 29 variants PipelineConfigParseError { error: String, }, ParserConfigParseError { endpoint_name: String, error: String, config: String, }, EncoderConfigParseError { endpoint_name: String, error: String, config: String, }, DuplicateInputEndpoint { endpoint_name: String, }, DuplicateInputStream { stream_name: String, }, DuplicateOutputEndpoint { endpoint_name: String, }, DuplicateOutputStream { stream_name: String, }, UnknownInputFormat { endpoint_name: String, format_name: String, }, UnknownOutputFormat { endpoint_name: String, format_name: String, }, UnknownInputTransport { endpoint_name: String, transport_name: String, }, UnknownOutputTransport { endpoint_name: String, transport_name: String, }, UnknownInputStream { endpoint_name: String, stream_name: String, }, UnknownOutputStream { endpoint_name: String, stream_name: String, }, UnknownIndex { endpoint_name: String, index_name: String, }, NotAnIndex { endpoint_name: String, index_name: String, }, InputFormatNotSupported { endpoint_name: String, error: String, }, OutputFormatNotSupported { endpoint_name: String, error: String, }, InputFormatNotSpecified { endpoint_name: String, }, OutputFormatNotSpecified { endpoint_name: String, }, InvalidEncoderConfig { endpoint_name: String, error: String, }, InvalidParserConfig { endpoint_name: String, error: String, }, InvalidTransportConfig { endpoint_name: String, error: String, }, InvalidOutputBufferConfig { endpoint_name: String, error: String, }, CyclicDependency { cycle: Vec<(String, String)>, }, EmptyStartAfter { endpoint_name: String, }, FtRequiresStorage, FtRequiresFtInput, DatafusionMemoryExceedsBudget { datafusion_memory_mb: u64, max_rss_mb: u64, }, InvalidLayout(LayoutError),
}
Controller configuration error.

Variants



PipelineConfigParseError

Failed to parse pipeline configuration.

Fields

error: String


ParserConfigParseError

Failed to parse parser configuration for an endpoint.

Fields

endpoint_name: String
error: String
config: String


EncoderConfigParseError

Failed to parse encoder configuration for an endpoint.

Fields

endpoint_name: String
error: String
config: String


DuplicateInputEndpoint

Input endpoint with this name already exists.

Fields

endpoint_name: String


DuplicateInputStream

Input table with this name already exists.

Fields

stream_name: String


DuplicateOutputEndpoint

Output endpoint with this name already exists.

Fields

endpoint_name: String


DuplicateOutputStream

Output view with this name already exists.

Fields

stream_name: String


UnknownInputFormat

Endpoint configuration specifies unknown input format name.

Fields

endpoint_name: String
format_name: String


UnknownOutputFormat

Endpoint configuration specifies unknown output format name.

Fields

endpoint_name: String
format_name: String


UnknownInputTransport

Endpoint configuration specifies unknown input transport name.

Fields

endpoint_name: String
transport_name: String


UnknownOutputTransport

Endpoint configuration specifies unknown output transport name.

Fields

endpoint_name: String
transport_name: String


UnknownInputStream

Endpoint configuration specifies an input stream name that is not found in the circuit catalog.

Fields

endpoint_name: String
stream_name: String


UnknownOutputStream

Endpoint configuration specifies an output stream name that is not found in the circuit catalog.

Fields

endpoint_name: String
stream_name: String


UnknownIndex

Endpoint configuration specifies an index name that is not found in the circuit catalog.

Fields

endpoint_name: String
index_name: String


NotAnIndex

Fields

endpoint_name: String
index_name: String


InputFormatNotSupported

Fields

endpoint_name: String
error: String


OutputFormatNotSupported

Fields

endpoint_name: String
error: String


InputFormatNotSpecified

Fields

endpoint_name: String


OutputFormatNotSpecified

Fields

endpoint_name: String


InvalidEncoderConfig

Fields

endpoint_name: String
error: String


InvalidParserConfig

Fields

endpoint_name: String
error: String


InvalidTransportConfig

Fields

endpoint_name: String
error: String


InvalidOutputBufferConfig

Fields

endpoint_name: String
error: String


CyclicDependency

Fields

cycle: Vec<(String, String)>


EmptyStartAfter

Fields

endpoint_name: String


FtRequiresStorage



FtRequiresFtInput



DatafusionMemoryExceedsBudget

datafusion_memory_mb was set to a value greater than or equal to the pipeline’s effective memory budget, which would leave no memory for the DBSP circuit.

Fields

datafusion_memory_mb: u64
max_rss_mb: u64


InvalidLayout(LayoutError)

Implementations

Source

impl ConfigError

pub fn pipeline_config_parse_error<E>(error: &E) -> Self
where E: ToString,

pub fn parser_config_parse_error<E>( endpoint_name: &str, error: &E, config: &str, ) -> Self
where E: ToString,

pub fn encoder_config_parse_error<E>( endpoint_name: &str, error: &E, config: &str, ) -> Self
where E: ToString,

pub fn duplicate_input_endpoint(endpoint_name: &str) -> Self

pub fn duplicate_input_stream(stream_name: &str) -> Self

pub fn unknown_input_format(endpoint_name: &str, format_name: &str) -> Self

pub fn unknown_input_transport( endpoint_name: &str, transport_name: &str, ) -> Self

pub fn duplicate_output_endpoint(endpoint_name: &str) -> Self

pub fn duplicate_output_stream(stream_name: &str) -> Self

pub fn unknown_output_format(endpoint_name: &str, format_name: &str) -> Self

pub fn unknown_output_transport( endpoint_name: &str, transport_name: &str, ) -> Self

pub fn unknown_input_stream(endpoint_name: &str, stream_name: &str) -> Self

pub fn unknown_output_stream(endpoint_name: &str, stream_name: &str) -> Self

pub fn unknown_index(endpoint_name: &str, index_name: &str) -> Self

pub fn not_an_index(endpoint_name: &str, index_name: &str) -> Self

pub fn input_format_not_supported(endpoint_name: &str, error: &str) -> Self

pub fn output_format_not_supported(endpoint_name: &str, error: &str) -> Self

pub fn input_format_not_specified(endpoint_name: &str) -> Self

pub fn output_format_not_specified(endpoint_name: &str) -> Self

pub fn invalid_encoder_configuration(endpoint_name: &str, error: &str) -> Self

pub fn invalid_parser_configuration(endpoint_name: &str, error: &str) -> Self

pub fn invalid_transport_configuration(endpoint_name: &str, error: &str) -> Self

pub fn invalid_output_buffer_configuration( endpoint_name: &str, error: &str, ) -> Self

pub fn cyclic_dependency(cycle: Vec<(String, String)>) -> Self

pub fn empty_start_after(endpoint_name: &str) -> Self