pub enum ControllerError {
Show 45 variants
IoError {
context: String,
io_error: Error,
backtrace: Backtrace,
},
SchemaParseError {
error: String,
},
SchemaValidationError {
error: String,
},
CheckpointParseError {
error: String,
},
CheckpointDoesNotMatchPipeline,
RestoreInProgress,
BootstrapInProgress,
StepError(StepError),
UnexpectedStep {
actual: Step,
expected: Step,
},
ReplayFailure {
error: String,
},
NotSupported {
error: String,
},
IrParseError {
error: String,
},
CliArgsError {
error: String,
},
Config {
config_error: Box<ConfigError>,
},
UnknownInputEndpoint {
endpoint_name: String,
},
PreprocessorCreateError {
endpoint_name: String,
error: String,
},
PostprocessorCreateError {
endpoint_name: String,
error: String,
},
UnknownOutputEndpoint {
endpoint_name: String,
},
ParseError {
endpoint_name: String,
error: Box<ParseError>,
},
EncodeError {
endpoint_name: String,
error: Error,
},
InputTransportError {
endpoint_name: String,
fatal: bool,
error: Error,
},
OutputTransportError {
endpoint_name: String,
fatal: bool,
error: Error,
},
CommandError {
endpoint_name: String,
error: String,
},
DbspError {
error: Error,
},
PrometheusError {
error: String,
},
DbspPanic,
ControllerPanic,
ControllerExit,
StorageError {
context: String,
error: StorageError,
backtrace: Box<Backtrace>,
},
EnterpriseFeature(&'static str),
SuspendError(SuspendError),
UnexpectedJsonStructure {
reason: String,
},
PipelineRestarted {
error: String,
},
UnknownEndpointInCompletionToken {
endpoint_id: u64,
},
CheckpointFetchError {
error: String,
},
CheckpointPushError {
error: String,
},
TransactionInProgress,
NoTransactionInProgress,
InvalidInitialStatus(RuntimeDesiredStatus),
InvalidStandby(&'static str),
InvalidStartupTransition {
from: RuntimeDesiredStatus,
to: RuntimeDesiredStatus,
},
BootstrapRejectedByUser,
BootstrapNotAllowed {
error: String,
},
UnexpectedBootstrap {
bootstrap_info: Option<BootstrapInfo>,
},
UnexpectedRuntimeVersion {
error: String,
},
}Expand description
Controller error.
Reports all errors that arise from operating a streaming pipeline consisting of input adapters, output adapters, and a DBSP circuit, via the controller API.
Variants
IoError
I/O error.
Fields
SchemaParseError
Error parsing program schema.
SchemaValidationError
Error validating program schema.
CheckpointParseError
Error parsing the checkpoint.
CheckpointDoesNotMatchPipeline
RestoreInProgress
Operation cannot be initiated now because the pipeline is being restored from a checkpoint.
BootstrapInProgress
Operation cannot be initiated now because the pipeline is bootstrapping new/modified views.
StepError(StepError)
Error in journal metadata.
UnexpectedStep
Unexpected step number.
ReplayFailure
Step replay failure.
NotSupported
Feature is not supported.
IrParseError
Error parsing program IR file.
CliArgsError
Error parsing CLI arguments.
Config
Invalid controller configuration.
Fields
config_error: Box<ConfigError>UnknownInputEndpoint
Unknown input endpoint name.
PreprocessorCreateError
Error creating a user-defined preprocessor
PostprocessorCreateError
Error creating a user-defined postprocessor
UnknownOutputEndpoint
Unknown output endpoint name.
ParseError
Error parsing input data.
Parser errors are expected to be recoverable, i.e., the parser should be able to successfully parse new valid inputs after an error.
EncodeError
Encode error.
Error encoding the last output batch. Encoder errors are expected to be recoverable, i.e., the encoder should be able to successfully parse new valid inputs after an error.
InputTransportError
Input transport endpoint error.
OutputTransportError
Output transport endpoint error.
CommandError
DbspError
Error evaluating the DBSP circuit.
PrometheusError
Error inside the Prometheus module.
DbspPanic
Panic inside the DBSP runtime.
ControllerPanic
Panic inside the DBSP controller.
ControllerExit
Controller terminated before command could be executed.
StorageError
Storage error.
Fields
error: StorageErrorEnterpriseFeature(&'static str)
Enterprise-only feature.
SuspendError(SuspendError)
Cannot checkpoint or suspend.
UnexpectedJsonStructure
An unexpected JSON serialized structure was encountered while processing the /stats endpoint.
PipelineRestarted
The request relates to an old incarnation of the pipeline.
UnknownEndpointInCompletionToken
Completion token specified non-existing endpoint id. This indicates that the endpoint was removed or the token is invalid.
CheckpointFetchError
Error fetching checkpoint from remote object storage.
CheckpointPushError
Error pushing checkpoint to remote object storage.
TransactionInProgress
NoTransactionInProgress
InvalidInitialStatus(RuntimeDesiredStatus)
Invalid initial desired status.
InvalidStandby(&'static str)
Invalid standby configuration,
InvalidStartupTransition
Invalid startup status transition.
BootstrapRejectedByUser
BootstrapNotAllowed
UnexpectedBootstrap
Fields
bootstrap_info: Option<BootstrapInfo>UnexpectedRuntimeVersion
Unexpected runtime version
Implementations
Sourceimpl ControllerError
impl ControllerError
pub fn io_error(context: impl Display, io_error: IoError) -> Self
pub fn not_supported(error: &str) -> Self
pub fn schema_parse_error(error: &str) -> Self
pub fn checkpoint_does_not_match_pipeline() -> Self
pub fn checkpoint_fetch_error(error: String) -> Self
pub fn checkpoint_push_error(error: String) -> Self
pub fn schema_validation_error(error: &str) -> Self
pub fn ir_parse_error(error: &str) -> Self
pub fn cli_args_error<E>(error: &E) -> Selfwhere
E: ToString,
pub fn unknown_input_endpoint(endpoint_name: &str) -> Self
pub fn unknown_output_endpoint(endpoint_name: &str) -> Self
pub fn pipeline_config_parse_error<E>(error: &E) -> Selfwhere
E: ToString,
pub fn parser_config_parse_error<E>(
endpoint_name: &str,
error: &E,
config: &str,
) -> Selfwhere
E: ToString,
pub fn encoder_config_parse_error<E>(
endpoint_name: &str,
error: &E,
config: &str,
) -> Selfwhere
E: ToString,
pub fn duplicate_input_endpoint(endpoint_name: &str) -> Self
pub fn duplicate_input_stream(stream_name: &str) -> Self
pub fn unknown_input_format(endpoint_name: &str, format_name: &str) -> Self
pub fn unknown_input_transport( endpoint_name: &str, transport_name: &str, ) -> Self
pub fn duplicate_output_endpoint(endpoint_name: &str) -> Self
pub fn duplicate_output_stream(stream_name: &str) -> Self
pub fn unknown_output_format(endpoint_name: &str, format_name: &str) -> Self
pub fn unknown_output_transport( endpoint_name: &str, transport_name: &str, ) -> Self
pub fn unknown_input_stream(endpoint_name: &str, stream_name: &str) -> Self
pub fn unknown_output_stream(endpoint_name: &str, stream_name: &str) -> Self
pub fn unknown_index(endpoint_name: &str, index_name: &str) -> Self
pub fn not_an_index(endpoint_name: &str, index_name: &str) -> Self
pub fn input_format_not_supported(endpoint_name: &str, error: &str) -> Self
pub fn output_format_not_supported(endpoint_name: &str, error: &str) -> Self
pub fn input_format_not_specified(endpoint_name: &str) -> Self
pub fn output_format_not_specified(endpoint_name: &str) -> Self
pub fn invalid_encoder_configuration(endpoint_name: &str, error: &str) -> Self
pub fn invalid_parser_configuration(endpoint_name: &str, error: &str) -> Self
pub fn invalid_transport_configuration(endpoint_name: &str, error: &str) -> Self
pub fn invalid_output_buffer_configuration( endpoint_name: &str, error: &str, ) -> Self
pub fn input_transport_error( endpoint_name: &str, fatal: bool, error: AnyError, ) -> Self
pub fn output_transport_error( endpoint_name: &str, fatal: bool, error: AnyError, ) -> Self
pub fn command_error(endpoint_name: &str, error: &str) -> Self
pub fn parse_error(endpoint_name: &str, error: ParseError) -> Self
pub fn encode_error(endpoint_name: &str, error: AnyError) -> Self
pub fn prometheus_error<E>(error: &E) -> Selfwhere
E: ToString,
pub fn dbsp_error(error: DbspError) -> Self
pub fn dbsp_panic() -> Self
pub fn controller_panic() -> Self
pub fn storage_error(context: impl Display, error: StorageError) -> Self
pub fn pipeline_restarted(error: &str) -> Self
pub fn unknown_endpoint_in_completion_token(endpoint_id: u64) -> Self
pub fn kind(&self) -> ErrorKind