pub struct ParseErrorInner { /* private fields */ }Implementations
Sourceimpl ParseErrorInner
impl ParseErrorInner
pub fn new( description: String, event_number: Option<u64>, field: Option<String>, invalid_text: Option<&str>, invalid_bytes: Option<&[u8]>, suggestion: Option<Cow<'static, str>>, error_tag: Option<String>, ) -> Self
Sourcepub fn text_event_error<E>(
msg: &str,
error: E,
event_number: u64,
invalid_text: Option<&str>,
suggestion: Option<Cow<'static, str>>,
) -> Selfwhere
E: ToString,
pub fn text_event_error<E>(
msg: &str,
error: E,
event_number: u64,
invalid_text: Option<&str>,
suggestion: Option<Cow<'static, str>>,
) -> Selfwhere
E: ToString,
Error parsing an individual event in a text-based input format (e.g., JSON, CSV).
Sourcepub fn text_envelope_error(
description: String,
invalid_text: &str,
suggestion: Option<Cow<'static, str>>,
) -> Self
pub fn text_envelope_error( description: String, invalid_text: &str, suggestion: Option<Cow<'static, str>>, ) -> Self
Error parsing a container, e.g., a JSON array, with multiple events.
Such errors cannot be attributed to an individual event numbers.
Sourcepub fn bin_event_error(
description: String,
event_number: u64,
invalid_bytes: &[u8],
suggestion: Option<Cow<'static, str>>,
) -> Self
pub fn bin_event_error( description: String, event_number: u64, invalid_bytes: &[u8], suggestion: Option<Cow<'static, str>>, ) -> Self
Error parsing an individual event in a binary input format (e.g., bincode).
Sourcepub fn bin_envelope_error(
description: String,
invalid_bytes: &[u8],
suggestion: Option<Cow<'static, str>>,
) -> Self
pub fn bin_envelope_error( description: String, invalid_bytes: &[u8], suggestion: Option<Cow<'static, str>>, ) -> Self
Error parsing a container with multiple events.
Such errors cannot be attributed to an individual event numbers.
pub fn get_error_tag(&self) -> Option<String>