StagedInputBuffer

Struct StagedInputBuffer 

pub struct StagedInputBuffer { /* private fields */ }
A wrapper around a StagedBuffers that implements the InputBuffer trait.

The StagedBuffers trait is similar to InputBuffer in that it supports flushing a set of tuples to the circuit. Unlike InputBuffer, it doesn’t support returning its size as a BufferSize. It also doesn’t support hashing and taking a subset of records.

This wrapper adds the former by storing BufferSize collected from InputBuffers used to create the StagedBuffers.

hash() and take_some() methods are unimplemented. Therefore this wrapper can only be safely used in contexts where these methods are not needed.

Implementations

Source

impl StagedInputBuffer

pub fn new(buffer: Box<dyn StagedBuffers>, size: BufferSize) -> Self