StreamSplitter

Struct StreamSplitter 

pub struct StreamSplitter { /* private fields */ }
Helper for breaking a stream of data into groups of records using a Splitter.

A Splitter finds breakpoints between records given data presented to it. This is a higher-level data structure that takes input data and breaks it into chunks.

Implementations

Source

impl StreamSplitter

pub fn new(splitter: Box<dyn Splitter>) -> Self

Returns a new stream splitter that finds breakpoints with splitter.

pub fn next(&mut self, eoi: bool) -> Option<&[u8]>

Returns the next full chunk of input, if any. eoi specifies whether the input stream is complete. If eoi is true and this function returns None, then there are no more chunks.

pub fn append(&mut self, data: &[u8])

Appends data to the data to be broken into chunks.

pub fn read( &mut self, file: &mut File, buffer_size: usize, limit: usize, ) -> Result<usize, IoError>

pub fn position(&self) -> u64

Returns the logical stream position of the next byte to be returned by the splitter.

pub fn seek(&mut self, offset: u64)

Sets the logical stream position of the next byte to be returned by the splitter to offset, and discards other state.

pub fn reset(&mut self)

Resets the splitter’s state as if it were newly created.