pub struct ConnectorHistogram {
pub name: &'static str,
pub help: &'static str,
pub snapshot: ExponentialHistogramSnapshot,
}Expand description
A connector histogram metric.
The histogram is exported in the unit it was recorded in, so name should
name that unit (for example, a histogram of microseconds should be named
..._microseconds).
Fields
name: &'static strMetric name; must be a valid Prometheus metric name component (no spaces,
no special characters other than _).
help: &'static strHuman-readable help text.
snapshot: ExponentialHistogramSnapshotThe recorded histogram.