PreprocessorFactory

Trait PreprocessorFactory 

pub trait PreprocessorFactory: Send + Sync {
    // Required method
    fn create(
        &self,
        config: &PreprocessorConfig,
    ) -> Result<Box<dyn Preprocessor>, PreprocessorCreateError>;
}
A factory that can create a new Preprocessor object.

Required Methods

fn create( &self, config: &PreprocessorConfig, ) -> Result<Box<dyn Preprocessor>, PreprocessorCreateError>

Create a new preprocessor based on the supplied configuration.

Arguments
  • config - Preprocessor-specific configuration.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors