ConnectorMetadata

Struct ConnectorMetadata 

pub struct ConnectorMetadata(/* private fields */);
Connector metadata attached to each input record.

Both the transport connector and the parser can add metadata attributes such as Kafka topic name or Avro schema id. These attributes are passed to the deserializer along with the actual record, which can use them to populate some of the table columns.

Implementations

Source

impl ConnectorMetadata

pub fn new() -> Self

pub fn insert(&mut self, name: &str, value: Variant)