InputQueue

Struct InputQueue 

pub struct InputQueue<A = (), B = Box<dyn InputBuffer>> {
    pub queue: Mutex<VecDeque<InputQueueEntry<A, B>>>,
    pub consumer: Box<dyn InputConsumer>,
    pub transaction_in_progress: AtomicBool,
}
A thread-safe queue for collecting and flushing input buffers.

Commonly used by InputReader implementations for staging buffers from worker threads.

Fields

queue: Mutex<VecDeque<InputQueueEntry<A, B>>>consumer: Box<dyn InputConsumer>transaction_in_progress: AtomicBool

Implementations

Source

impl<A, B: InputBuffer> InputQueue<A, B>

pub fn new(consumer: Box<dyn InputConsumer>) -> Self

pub fn push_entry(&self, entry: InputQueueEntry<A, B>, errors: Vec<ParseError>)

pub fn push_with_aux( &self, (buffer, errors): (Option<B>, Vec<ParseError>), timestamp: DateTime<Utc>, aux: A, )

Appends buffer, to the queue, and associates it with aux. Reports to the controller that errors have occurred during parsing.

pub fn flush_with_aux( &self, ) -> (BufferSize, Option<Xxh3Default>, Vec<(DateTime<Utc>, A)>)

Flushes a batch of records to the circuit and returns the auxiliary data that was associated with those records.

This always flushes whole buffers to the circuit (with flush), since auxiliary data is associated with a whole buffer rather than with individual records. If the auxiliary data type A is (), then [InputQueue<()>::flush] avoids that and so is a better choice.

pub fn flush_with_aux_until( &self, stop_at: &dyn Fn(&A) -> bool, ) -> (BufferSize, Option<Xxh3Default>, Vec<(DateTime<Utc>, A)>)

Flushes a batch of records to the circuit and returns the auxiliary data that was associated with those records.

Stops after flushing at least max_batch_size records or after flushing a buffer whose auxiliary data satisfies the stop_at predicate, whichever happens first.

This always flushes whole buffers to the circuit (with flush), since auxiliary data is associated with a whole buffer rather than with individual records. If the auxiliary data type A is (), then [InputQueue<()>::flush] avoids that and so is a better choice.

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

Source

impl InputQueue<(), Box<dyn InputBuffer>>

pub fn push( &self, (buffer, errors): (Option<Box<dyn InputBuffer>>, Vec<ParseError>), timestamp: DateTime<Utc>, )

Appends buffer, if nonempty,to the queue. Reports to the controller thaterrors` occurred during parsing.

pub fn queue(&self)

Flushes a batch of records to the circuit and reports to the consumer that it was done.

Only non-fault-tolerant input adapters can use this.