pub struct OutputCollectionHandles {
pub key_schema: Option<Relation>,
pub value_schema: Relation,
pub index_of: Option<SqlIdentifier>,
pub integrate_handle_is_indexed: bool,
pub integrate_handle: Option<Arc<dyn SerBatchReaderHandle>>,
pub delta_handle: Box<dyn SerBatchReaderHandle>,
pub enable_count: Arc<AtomicUsize>,
}Expand description
A set of stream handles associated with each output collection.
Fields
key_schema: Option<Relation>value_schema: Relationindex_of: Option<SqlIdentifier>integrate_handle_is_indexed: boolWhether the integrate handle is an indexed Z-set.
integrate_handle: Option<Arc<dyn SerBatchReaderHandle>>A handle to a snapshot of a materialized table/view.
delta_handle: Box<dyn SerBatchReaderHandle>A stream of changes to the collection.
enable_count: Arc<AtomicUsize>Reference to the enable count of the accumulator used to collect updates to this stream. Incremented every time an output connector is attached to this stream; decremented when the output connector is detached.