pub struct StreamSplitter { /* private fields */ }Expand description
Implementations
Sourceimpl StreamSplitter
impl StreamSplitter
Sourcepub fn new(splitter: Box<dyn Splitter>) -> Self
pub fn new(splitter: Box<dyn Splitter>) -> Self
Returns a new stream splitter that finds breakpoints with splitter.
Sourcepub fn next(&mut self, eoi: bool) -> Option<&[u8]>
pub fn next(&mut self, eoi: bool) -> Option<&[u8]>
Returns the next full chunk of input, if any. eoi specifies whether
the input stream is complete. If eoi is true and this function returns
None, then there are no more chunks.
pub fn read( &mut self, file: &mut File, buffer_size: usize, limit: usize, ) -> Result<usize, IoError>
Sourcepub fn position(&self) -> u64
pub fn position(&self) -> u64
Returns the logical stream position of the next byte to be returned by the splitter.