Encoder

Trait Encoder 

pub trait Encoder: Send {
    // Required methods
    fn consumer(&mut self) -> &mut dyn OutputConsumer;
    fn encode(&mut self, batch: Arc<dyn SerBatchReader>) -> AnyResult<()>;
}

Required Methods

fn consumer(&mut self) -> &mut dyn OutputConsumer

Returns a reference to the consumer that the encoder is connected to.

fn encode(&mut self, batch: Arc<dyn SerBatchReader>) -> AnyResult<()>

Encode a batch of updates, push encoded buffers to the consumer using [OutputConsumer::push_buffer].

Implementors