Data postprocessing layer for connectors.
This module provides a postprocessing framework that allows data transformation after encoding and before transmission.
The postprocessing layer fits between encoding and transport in the data pipeline:
Circuit → Encoder → Postprocessor → TransportStructs
- Postprocessor
Registry - A registry where all factories that can create Postprocessors are registered.
Enums
- Postprocessor
Create Error - Errors that can occur during creation of a postprocessor.
Traits
- Postprocessor
- Trait for postprocessing encoded output data before transmission.
- Postprocessor
Factory - A factory that can create a new Postprocessor object.