pub struct InputQueue<A = (), B = Box<dyn InputBuffer>> {
pub queue: Mutex<VecDeque<InputQueueEntry<A, B>>>,
pub consumer: Box<dyn InputConsumer>,
pub transaction_in_progress: AtomicBool,
}Expand description
A thread-safe queue for collecting and flushing input buffers.
Commonly used by InputReader implementations for staging buffers from
worker threads.
Fields
queue: Mutex<VecDeque<InputQueueEntry<A, B>>>consumer: Box<dyn InputConsumer>transaction_in_progress: AtomicBoolImplementations
Sourceimpl<A, B: InputBuffer> InputQueue<A, B>
impl<A, B: InputBuffer> InputQueue<A, B>
pub fn new(consumer: Box<dyn InputConsumer>) -> Self
pub fn push_entry(&self, entry: InputQueueEntry<A, B>, errors: Vec<ParseError>)
Sourcepub fn push_with_aux(
&self,
(buffer, errors): (Option<B>, Vec<ParseError>),
timestamp: DateTime<Utc>,
aux: A,
)
pub fn push_with_aux( &self, (buffer, errors): (Option<B>, Vec<ParseError>), timestamp: DateTime<Utc>, aux: A, )
Appends buffer, to the queue, and associates it with aux. Reports
to the controller that errors have occurred during parsing.
Sourcepub fn flush_with_aux(
&self,
) -> (BufferSize, Option<Xxh3Default>, Vec<(DateTime<Utc>, A)>)
pub fn flush_with_aux( &self, ) -> (BufferSize, Option<Xxh3Default>, Vec<(DateTime<Utc>, A)>)
Flushes a batch of records to the circuit and returns the auxiliary data that was associated with those records.
This always flushes whole buffers to the circuit (with flush),
since auxiliary data is associated with a whole buffer rather than with
individual records. If the auxiliary data type A is (), then
[InputQueue<()>::flush] avoids that and so is a better choice.
Sourcepub fn flush_with_aux_until(
&self,
stop_at: &dyn Fn(&A) -> bool,
) -> (BufferSize, Option<Xxh3Default>, Vec<(DateTime<Utc>, A)>)
pub fn flush_with_aux_until( &self, stop_at: &dyn Fn(&A) -> bool, ) -> (BufferSize, Option<Xxh3Default>, Vec<(DateTime<Utc>, A)>)
Flushes a batch of records to the circuit and returns the auxiliary data that was associated with those records.
Stops after flushing at least max_batch_size records or after flushing a
buffer whose auxiliary data satisfies the stop_at predicate, whichever
happens first.
This always flushes whole buffers to the circuit (with flush),
since auxiliary data is associated with a whole buffer rather than with
individual records. If the auxiliary data type A is (), then
[InputQueue<()>::flush] avoids that and so is a better choice.
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
Sourceimpl InputQueue<(), Box<dyn InputBuffer>>
impl InputQueue<(), Box<dyn InputBuffer>>
Sourcepub fn push(
&self,
(buffer, errors): (Option<Box<dyn InputBuffer>>, Vec<ParseError>),
timestamp: DateTime<Utc>,
)
pub fn push( &self, (buffer, errors): (Option<Box<dyn InputBuffer>>, Vec<ParseError>), timestamp: DateTime<Utc>, )
Appends buffer, if nonempty,to the queue. Reports to the controller thaterrors` occurred during parsing.